NLSL: iterat.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Modules | Variables
iterat.f90 File Reference

Go to the source code of this file.

## Modules
module | iterat

## Variables
integer, save | iterat::iter
integer, save | iterat::iwflag
double precision, save | iterat::fnorm
double precision, save | iterat::chisqr
double precision, save | iterat::rdchsq
double precision, save | iterat::ch2bnd
double precision, save | iterat::chnbnd
double precision, save | iterat::confid
double precision, save | iterat::delchi1
double precision, save | iterat::qfit
double precision, save | iterat::f2bnd
double precision, save | iterat::fnbnd
double precision, save | iterat::tbound
double precision, save | iterat::fnmin
logical, save | iterat::newitr
logical, save | iterat::covarok
logical, save | iterat::xreset